==> claromentis-framework-9.6.6-26891208.zip: web/intranet/stat/classes/StatProviderInterface.php <==
<?php
namespace Claromentis\Stat;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array();
use Claromentis\Core\DAL;
use Date;




interface StatProviderInterface
{
    
    
    
    
    
    
    public function GetStatCollectorData() : array;
    
    
    
    
    
    
    public function SetStatReporter(StatReporter $statreporter);
    
    
    
    
    
    
    public function GetName() : string;
    
    
    
    
    
    
    public function GetIconClass() : string;
    
    
    
    
    
    
    public function GetChartType() : string;
    
    
    
    
    
    
    public function GetSeries() : array;
    
    
    
    
    
    
    public function GetSeriesTooltips() : array;
    
    
    
    
    
    
    
    public function GetSeriesData(int $chart_series) : array;
    
    
    
    
    
    
    
    
    public function GetAllSeriesTotalCount() : int;
    
    
    
    
    
    
    public function GetAllSeriesTotalCountText() : string;
    
    
    
    
    
    
    public function GetAllSeriesDailyAverageCount() : float;
    
    
    
    
    
    
    public function GetAllSeriesDailyAverageCountText() : string;
    
    
    
    
    
    
    public function GetPageTitle() : string;
    
    
    
    
    
    
    public function GetTemplateFilename() : string;
    
    
    
    
    
    
    
    
    
    public function GetTemplateArgs(Date $date_from, Date $date_to) : array;
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/stat/classes/StatProviderInterface.php <==
<?php
namespace Claromentis\Stat;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array();
use Claromentis\Core\DAL;
use Date;




interface StatProviderInterface
{
    
    
    
    
    
    
    public function GetStatCollectorData() : array;
    
    
    
    
    
    
    public function SetStatReporter(StatReporter $statreporter);
    
    
    
    
    
    
    public function GetName() : string;
    
    
    
    
    
    
    public function GetIconClass() : string;
    
    
    
    
    
    
    public function GetChartType() : string;
    
    
    
    
    
    
    public function GetSeries() : array;
    
    
    
    
    
    
    public function GetSeriesTooltips() : array;
    
    
    
    
    
    
    
    public function GetSeriesData(int $chart_series) : array;
    
    
    
    
    
    
    
    
    public function GetAllSeriesTotalCount() : int;
    
    
    
    
    
    
    public function GetAllSeriesTotalCountText() : string;
    
    
    
    
    
    
    public function GetAllSeriesDailyAverageCount() : float;
    
    
    
    
    
    
    public function GetAllSeriesDailyAverageCountText() : string;
    
    
    
    
    
    
    public function GetPageTitle() : string;
    
    
    
    
    
    
    public function GetTemplateFilename() : string;
    
    
    
    
    
    
    
    
    
    public function GetTemplateArgs(Date $date_from, Date $date_to) : array;
}
